#
# spec file for package seahorse-nautilus
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           seahorse-nautilus
Version:        3.11.92+95
Release:        2.0.2.1.sr20250601
Summary:        Extension for nautilus which allows encryption and decryption of files
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            http://live.gnome.org/Seahorse
Source:         %{name}-%{version}.tar.xz
Patch0:         gpgme-2.0.0.patch
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cryptui-0.0) >= 3.9.90
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gcr-3) > 3.4.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.44
BuildRequires:  pkgconfig(glib-2.0) >= 2.44
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gpgme)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.18.0
BuildRequires:  pkgconfig(libnautilus-extension-4) >= 43.rc

%description
Seahorse nautilus is an extension for nautilus which allows encryption
and decryption of OpenPGP files using GnuPG.

%package -n nautilus-extension-seahorse
Summary:        Extension for nautilus which allows encryption and decryption of files
Group:          Productivity/Security
Supplements:    (seahorse and nautilus)
# For people looking for the upstream name, and to make lang package
# installable
Provides:       %{name} = %{version}

%description -n nautilus-extension-seahorse
Seahorse nautilus is an extension for nautilus which allows encryption
and decryption of OpenPGP files using GnuPG.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D check-compatible-gpg=false \
	-D libnotify=false \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}

%files -n nautilus-extension-seahorse
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md THANKS
%{_bindir}/seahorse-tool
%{_libdir}/nautilus/extensions-4/libnautilus-seahorse.so
%{_datadir}/applications/seahorse-pgp*.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.seahorse.nautilus.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.seahorse.nautilus.window.gschema.xml
%{_mandir}/man1/seahorse-tool.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sat Jun 14 2025 Andreas Stieger <andreas.stieger@gmx.de>
- fix build with gpgme >=2.0.0 gpgme-2.0.0.patch boo#1244605
* Thu Sep 15 2022 bjorn.lie@gmail.com
- Update to version 3.11.92+95:
  * libnautilus-extension: Prefer libnautilus-extension-4
  * nautilus extension: Port to libnautilus-extension-4
  * Add gpg version 2.3 so seahorse-nautilus will build
  * Stop including deprecated nautilus extension headers.
  * Fix UI files usage
- Switch to source service git checkout.
- Changes in BuildRequires:
  + Dropped: intltool, update-desktop-files,
    pkgconfig(libnautilus-extension) and
    glib2_gsettings_schema_requires macro.
  + Added: meson and pkgconfig(libnautilus-extension-4).
- Switched to meson macros and dropped sed call adding supported
  versions of gpg and drop post(un) handling since we now rely on
  filetriggers as well as suse_update_desktop_file macro calls.
- Update Supplements to current standard.
* Wed Sep 29 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 2.3 to the list of accepted GPG versions.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Aug 29 2017 dimstar@opensuse.org
- Add 2.2 to the list of accepted GPG versions.
* Tue Feb  9 2016 egeorget@openmailbox.org
- Move seahorse-nautilus-lang recommends from main package to
  nautilus-extension-seahorse: there is no binary main package
  produce (%%name is also provided by nautilus-extension-seahorse).
* Tue Dec 16 2014 dimstar@opensuse.org
- Inject version 2.1 as acceptable gpg version into configure:
  GPG 2.1 is verified to be compatible and supported.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Warn when signatures are valid but untrusted (bgo#708640).
  + License update (FSF address).
  + Documentation fixes.
  + Updated translations.
* Thu Oct 17 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + no changes since previous release.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Add correct flag for reaping the progress child (bgo#697895).
  + Add support for symmetric encryption in seahorse-tool
    (bgo#325803).
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + No changes since previous release.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Updated translatons.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fix the GSettings schema.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Stable release: no changes since previous release.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Updated translations
- Changes from version 3.5.4:
  + Update for newer Gtk and Glib
  + Use Gcr library for prompting of passwords
  + Migrate from GConf to GSettings
  + Fix several crashers
  + Updated translations.
- Add pkgconfig(gcr-3.0) BuildRequires: new dependency.
- Drop pkgconfig(gconf-2.0) BuildRequires: no longer needed after
  the port to GSettings.
- Add glib2_gsettings_schema_* macro handling.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + No changes.
* Mon Oct 31 2011 dimstar@opensuse.org
- Initial unstable release, split out from seahorse-plugins
  (version 3.3.1).
